pub enum SmsDevError {
Http(Error),
Api {
code: String,
description: String,
},
UrlParse(ParseError),
Json(Error),
UnexpectedResponse(String),
}Expand description
All errors that can be produced by the SmsDev SDK.
Variants
Http(Error)
An HTTP-level error returned by reqwest.
Api
The API returned a response with situacao = "ERROR".
Fields
UrlParse(ParseError)
A URL could not be constructed from the provided parameters.
Json(Error)
JSON serialisation / deserialisation error.
UnexpectedResponse(String)
The API returned an unexpected or empty response body.